==> codecommit-2.13.5-sources.jar: software/amazon/awssdk/services/codecommit/paginators/ListRepositoriesForApprovalRuleTemplateIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.codecommit.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.codecommit.CodeCommitClient;
import software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest;
import software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.codecommit.CodeCommitClient#listRepositoriesForApprovalRuleTemplatePaginator(software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse} that can be
 * used to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client.listRepositoriesForApprovalRuleTemplatePaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client
 *             .listRepositoriesForApprovalRuleTemplatePaginator(request);
 *     for (software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client.listRepositoriesForApprovalRuleTemplatePaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listRepositoriesForApprovalRuleTemplate(software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListRepositoriesForApprovalRuleTemplateIterable implements
        SdkIterable<ListRepositoriesForApprovalRuleTemplateResponse> {
    private final CodeCommitClient client;

    private final ListRepositoriesForApprovalRuleTemplateRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListRepositoriesForApprovalRuleTemplateIterable(CodeCommitClient client,
            ListRepositoriesForApprovalRuleTemplateRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListRepositoriesForApprovalRuleTemplateResponseFetcher();
    }

    @Override
    public Iterator<ListRepositoriesForApprovalRuleTemplateResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListRepositoriesForApprovalRuleTemplateResponseFetcher implements
            SyncPageFetcher<ListRepositoriesForApprovalRuleTemplateResponse> {
        @Override
        public boolean hasNextPage(ListRepositoriesForApprovalRuleTemplateResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListRepositoriesForApprovalRuleTemplateResponse nextPage(
                ListRepositoriesForApprovalRuleTemplateResponse previousPage) {
            if (previousPage == null) {
                return client.listRepositoriesForApprovalRuleTemplate(firstRequest);
            }
            return client.listRepositoriesForApprovalRuleTemplate(firstRequest.toBuilder().nextToken(previousPage.nextToken())
                    .build());
        }
    }
}

==> codecommit-2.17.241-sources.jar: software/amazon/awssdk/services/codecommit/paginators/ListRepositoriesForApprovalRuleTemplateIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.codecommit.paginators;

import java.util.Iterator;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.codecommit.CodeCommitClient;
import software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest;
import software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.codecommit.CodeCommitClient#listRepositoriesForApprovalRuleTemplatePaginator(software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse} that can be
 * used to iterate through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client.listRepositoriesForApprovalRuleTemplatePaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client
 *             .listRepositoriesForApprovalRuleTemplatePaginator(request);
 *     for (software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.codecommit.paginators.ListRepositoriesForApprovalRuleTemplateIterable responses = client.listRepositoriesForApprovalRuleTemplatePaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of maxResults won't limit the number of results you get with the paginator.
 * It only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listRepositoriesForApprovalRuleTemplate(software.amazon.awssdk.services.codecommit.model.ListRepositoriesForApprovalRuleTemplateRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListRepositoriesForApprovalRuleTemplateIterable implements
        SdkIterable<ListRepositoriesForApprovalRuleTemplateResponse> {
    private final CodeCommitClient client;

    private final ListRepositoriesForApprovalRuleTemplateRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListRepositoriesForApprovalRuleTemplateIterable(CodeCommitClient client,
            ListRepositoriesForApprovalRuleTemplateRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListRepositoriesForApprovalRuleTemplateResponseFetcher();
    }

    @Override
    public Iterator<ListRepositoriesForApprovalRuleTemplateResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    private class ListRepositoriesForApprovalRuleTemplateResponseFetcher implements
            SyncPageFetcher<ListRepositoriesForApprovalRuleTemplateResponse> {
        @Override
        public boolean hasNextPage(ListRepositoriesForApprovalRuleTemplateResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListRepositoriesForApprovalRuleTemplateResponse nextPage(
                ListRepositoriesForApprovalRuleTemplateResponse previousPage) {
            if (previousPage == null) {
                return client.listRepositoriesForApprovalRuleTemplate(firstRequest);
            }
            return client.listRepositoriesForApprovalRuleTemplate(firstRequest.toBuilder().nextToken(previousPage.nextToken())
                    .build());
        }
    }
}
